@@ -169,10 +169,14 @@ static void
 cal_fill_event_list_ui(CalHomePlugin* desktop_plugin)
 {
   GtkTreeIter iter;
-  gtk_container_foreach (GTK_CONTAINER (desktop_plugin->event_list_container), (GtkCallback) gtk_widget_destroy, NULL);
+  gtk_container_foreach(GTK_CONTAINER(desktop_plugin->event_list_container), (GtkCallback)gtk_widget_destroy, NULL);
+  gint row_count = gtk_tree_model_iter_n_children(GTK_TREE_MODEL(desktop_plugin->event_list), NULL);
+
+  gtk_table_resize(GTK_TABLE(desktop_plugin->event_list_container),row_count,3);
   if(gtk_tree_model_get_iter_first(GTK_TREE_MODEL(desktop_plugin->event_list),
 				   &iter))
   {
+    int i = 0;
     do
     {
       gchar* time;
@@ -210,17 +214,26 @@ cal_fill_event_list_ui(CalHomePlugin* desktop_plugin)
 				      GTK_STATE_NORMAL,
 				      "DefaultTextColor");
 
-      gtk_misc_set_alignment (GTK_MISC (time_label), 0, 0); 
-      gtk_misc_set_alignment (GTK_MISC (summary_label), 0, 0);
-      gtk_misc_set_alignment (GTK_MISC (cal_image), 1, 0);
-      gtk_label_set_ellipsize(GTK_LABEL(summary_label), PANGO_ELLIPSIZE_END);
-      gtk_box_pack_start(GTK_BOX(line), time_label, FALSE, FALSE, 8);
-      gtk_box_pack_start(GTK_BOX(line), summary_label, TRUE, TRUE, 0);
-      gtk_box_pack_start(GTK_BOX(line), cal_image, FALSE, FALSE, 8);
-      gtk_box_pack_start(GTK_BOX(desktop_plugin->event_list_container), line, TRUE, FALSE, 4);
-      
-
+      gtk_misc_set_alignment(GTK_MISC(time_label), 0.0f, 0.5f);
+      gtk_misc_set_alignment(GTK_MISC(summary_label), 0.0f, 0.5f);
+      gtk_misc_set_alignment(GTK_MISC(cal_image), 1.0f, 0.5f);
 
+      gtk_table_attach(GTK_TABLE(desktop_plugin->event_list_container),
+		       time_label, 0, 1, i, i+1,
+		       GtkAttachOptions(GTK_FILL | GTK_SHRINK),
+		       GTK_FILL,
+		       5, 5);
+      gtk_table_attach(GTK_TABLE(desktop_plugin->event_list_container),
+		       summary_label, 1, 2, i, i+1,
+		       GtkAttachOptions(GTK_FILL | GTK_EXPAND),
+		       GTK_FILL,
+		       0, 5);
+      gtk_table_attach(GTK_TABLE(desktop_plugin->event_list_container),
+		       cal_image, 2, 3, i, i+1,
+		       GTK_FILL,
+		       GTK_FILL,
+		       4, 5);
+      ++i;
     }while(gtk_tree_model_iter_next(GTK_TREE_MODEL(desktop_plugin->event_list),
 				    &iter));
   }
@@ -353,12 +366,14 @@ cal_condense_ccomponents_set_to_list_store(const SortedCComponentSet& ccomponent
     time_t event_end_time = (*event_iter)->getDateEnd();
     time_t event_time_offset = (*event_iter)->getTzOffset();
     struct tm* time = localtime(&event_start_time);
+
     if(CMulticalendar::MCInstance()->getSystemTimeZone() != (*event_iter)->getTzid() &&
        (*event_iter)->getAllDay())
     {
       event_end_time += event_time_offset - system_time_offset;
       event_start_time += event_time_offset - system_time_offset;
     }
+
     if(earliest_update_end_time>event_end_time)
       earliest_update_end_time = end_time+60;
     if(date_today_time < event_start_time &&
@@ -396,7 +411,7 @@ cal_condense_ccomponents_set_to_list_store(const SortedCComponentSet& ccomponent
     {
       if(desktop_plugin->show_week_day_name)
       {
-	gchar* tt = g_strdup_printf("<tt>%s</tt>", dgettext("hildon-libs","wdgt_va_date_day_name_short"));
+	gchar* tt = g_strdup_printf("%s", dgettext("hildon-libs","wdgt_va_date_day_name_short"));
 	strftime(buf, 255, tt, time);
 	g_free(tt);
       }
@@ -505,6 +520,7 @@ calendar_getComponents(int calendarId,
   error = CALENDAR_OPERATION_SUCCESSFUL;
   
   CCalendarDB *pDb = CCalendarDB::Instance();
+  time_t system_time_offset = CMulticalendar::MCInstance()->getSystemTimeShift();
 
   int iNewStDate = 0;
   int iNewEndDate = 0;
@@ -512,7 +528,6 @@ calendar_getComponents(int calendarId,
   int time_diff = time_get_time_diff (iStDate, mc->getSystemTimeZone().c_str(), "UTC");
   iNewStDate = iStDate + time_diff;
   iNewEndDate = iEndDate + time_diff;
-  
 
   if (pDb == 0) 
   {
@@ -522,7 +537,7 @@ calendar_getComponents(int calendarId,
   char *sqlQuery = 
     sqlite3_mprintf(
 		    "select * from %s where "
-		    "%s = %d  AND  %s = %d AND %s < %d AND %s > %d AND (%s != %d AND %s != %d) "
+		    "%s = %d  AND  %s = %d AND (%s + %s) < %d AND (%s + %s) > %d AND (%s != %d AND %s != %d) "
 		    "union select * from %s where "
 		    "%s = %d AND  %s = %d  AND (%s = 2  OR allday = 1) AND (%s + %s)= %d AND (%s != %d AND %s != %d) " 
 		    "union select * from %s where "
@@ -531,7 +546,7 @@ calendar_getComponents(int calendarId,
 		    "%s = %d AND %s = %d  AND allday = 1 AND (%s = %d OR %s = %d) AND (%d < (%s + %s) OR %d = %s) "
 		    "LIMIT %d OFFSET %d",
 		    COMPONENTS_TABLE,ENTRY_FIELD_CALID, calendarId,
-		    ENTRY_FIELD_TYPE, type,ENTRY_FIELD_DTSTART, iEndDate,ENTRY_FIELD_DTEND, iStDate,
+		    ENTRY_FIELD_TYPE, type,ENTRY_FIELD_DTSTART, ENTRY_FIELD_TZOFFSET, iNewEndDate,ENTRY_FIELD_DTEND, ENTRY_FIELD_TZOFFSET, iNewStDate,
 		    ENTRY_FIELD_FLAGS, HAS_RECURRENCE,ENTRY_FIELD_FLAGS, HAS_RECURRENCE_ALARM,
 		    
 		    COMPONENTS_TABLE,ENTRY_FIELD_CALID, calendarId, ENTRY_FIELD_TYPE, type, ENTRY_FIELD_TYPE,
@@ -682,20 +697,14 @@ cal_read_ccomponents_for_calendar(CCalendar* calendar,
   int offset = 0;
   int size = 0;
   int limit = 500;
+  time_t system_time_offset = CMulticalendar::MCInstance()->getSystemTimeShift();
+  string system_time_zone = CMulticalendar::MCInstance()->getSystemTimeZone();
   do
   {
     int event_type = E_EVENT;
     if(birthday_only)
       event_type = E_BDAY;
     gchar buf[255];
-    /*
-    vector<CComponent*> calendars_components = calendar->getComponents(event_type,
-								       start_time,
-								       end_time,
-								       limit,
-								       offset,
-								       error);
-    */
 
     vector<CComponent*> calendars_components = calendar_getComponents(calendar->getCalendarId(),
 								      event_type,
@@ -708,11 +717,14 @@ cal_read_ccomponents_for_calendar(CCalendar* calendar,
     offset=limit+1;
     limit+=500;
     time_t last_start_date = start_time;
+    struct tm today_midnight; 
+    
+    cal_home_time_today_midnight(&today_midnight);
+    time_t today_midnight_time = mktime(&today_midnight);
     for(int k = 0;k<calendars_components.size();++k)
     {
       CComponent* component = calendars_components[k];
 
-      time_t event_time_offset = component->getTzOffset();
       vector<time_t> instance_times =
 	component->getInstanceTimes(last_start_date, 
 				    end_time);
@@ -783,11 +795,7 @@ cal_read_ccomponents_all_visible(SortedCComponentSet& all_components,
 					end_time,
 					all_components, FALSE,
 					desktop_plugin);
-      /* cal_read_ccomponents_for_calendar(cal, */
-      /* 					start_time, */
-      /* 					-1, */
-      /* 					all_components, FALSE, */
-      /* 					desktop_plugin); */
+
       // gnark, birthday events start and end
       // at 00:00:00
 
